@@ -62,7 +62,8 @@ class POI:
         self.e_name = gtk.Entry()
         dlg.vbox.pack_start(self.e_name, True)
 
-        bt_add = gtk.Button("Add")
+        bt_add = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add")
         bt_add.connect("clicked", self.on_bt_add, dlg, dialog)
         dlg.vbox.pack_start(bt_add, True)
 
@@ -143,7 +144,8 @@ class POI:
             hbox.pack_start(l,False)
             l = gtk.Label("")
             hbox.pack_start(l,True)
-            bt = gtk.Button("del")
+            bt = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"del")
             bt.connect( "clicked", self.on_bt_delete_poi, p[0], d )
             hbox.pack_start(bt,False)
             mvbox.pack_start(hbox,False)
@@ -170,11 +172,13 @@ class POI:
     def get_menu_widgets(self, dialog):
         hbox = gtk.HBox()
 
-        bt_add = gtk.Button("Add")
+        bt_add = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add")
         bt_add.connect("clicked", self.on_add, dialog)
         hbox.pack_start( bt_add, True)
 
-        bt_edit = gtk.Button("Actions(%i)"%len(self.poi))
+        bt_edit = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Actions(%i)"%len(self.poi))
         bt_edit.connect("clicked", self.on_bt_edit )
         hbox.pack_start( bt_edit, False)
 
